@@ -181,11 +181,13 @@ class BaseManager(Asterisk.Logging.InstanceLogger):
 
     _AST_BANNERS = [
         'Asterisk Call Manager/1.0\r\n',
-        'Asterisk Call Manager/1.1\r\n'
+        'Asterisk Call Manager/1.1\r\n',
+        'Asterisk Call Manager/1.2\r\n',
     ]
 
 
-    def __init__(self, address, username, secret, listen_events = True):
+    def __init__(self, address, username, secret, listen_events=True,
+            timeout=None):
         '''
         Provide communication methods for the PBX instance running at
         <address>. Authenticate using <username> and <secret>. Receive event
@@ -203,6 +205,7 @@ class BaseManager(Asterisk.Logging.InstanceLogger):
         self.log.debug('Initialising.')
 
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        sock.settimeout(timeout)
         sock.connect(address)
 
         self.file = sock.makefile('r+', 0) # line buffered.
@@ -893,9 +896,10 @@ class CoreActions(object):
         })
 
         return self._translate_response(self.read_response(id))
- 
+
 
     def SipShowPeer(self, peer):
+        'Fetch the status of SIP peer <peer>.'
         id = self._write_action('SIPshowpeer', {'Peer': peer})
         showpeer = self._translate_response(self.read_response(id))
         del showpeer['Response']
@@ -913,7 +917,7 @@ class CoreActions(object):
             event = self.strip_evinfo(event)
             name = event.pop('Channel')
             channels[name] = event
-    
+
         def StatusComplete(self, event):
             stop_flag[0] = True
 
